<?php
add_action( 'customize_register', 'potenza_customize_register', 100 );
/**
 * Registers all theme-related options to the Customizer.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function potenza_customize_register( $wpc ) {

	$wpc->add_section( 'header', array(
		'title'       => esc_html_x( 'Header Options', 'customizer section title', 'potenza' ),
		'priority'    => 1
	) );

	$wpc->get_panel( 'nav_menus' )->priority = 2;

	$wpc->add_section( 'layout', array(
		'title'    => esc_html_x( 'Layout Options', 'customizer section title', 'potenza' ),
		'priority' => 20
	) );

	$wpc->add_section( 'typography', array(
		'title'    => _x( 'Typography Options', 'customizer section title', 'potenza' ),
		'priority' => 30
	) );

	$wpc->get_section( 'colors' )->title    = esc_html__( 'Content Colors', 'potenza' );
	$wpc->get_section( 'colors' )->priority = 40;

	$wpc->add_section( 'sidebar', array(
		'title'       => esc_html_x( 'Sidebar Colors', 'customizer section title', 'potenza' ),
		'description' => esc_html__( 'These options affect your sidebar (when visible).', 'potenza' ),
		'priority'    => 50
	) );

	// The following line doesn't work in a some PHP versions. Apparently, get_panel( 'widgets' ) returns an array,
	// therefore a cast to object is needed. http://wordpress.stackexchange.com/questions/160987/warning-creating-default-object-when-altering-customize-panels
	//$wpc->get_panel( 'widgets' )->priority = 55;
	$panel_widgets = (object) $wpc->get_panel( 'widgets' );
	$panel_widgets->priority = 55;

	$wpc->add_section( 'social', array(
		'title'       => esc_html_x( 'Social Networks', 'customizer section title', 'potenza' ),
		'description' => esc_html__( 'Enter your social network URLs. Leaving a URL empty will hide its respective icon.', 'potenza' ),
		'priority'    => 60
	) );

	$wpc->add_section( 'single_post', array(
		'title'       => esc_html_x( 'Posts Options', 'customizer section title', 'potenza' ),
		'description' => esc_html__( 'These options affect your individual posts.', 'potenza' ),
		'priority'    => 70
	) );

	$wpc->add_section( 'footer', array(
		'title'    => esc_html_x( 'Footer Options', 'customizer section title', 'potenza' ),
		'priority' => 100
	) );

	// Section 'static_front_page' is not defined when there are no pages.
	if ( get_pages() ) {
		$wpc->get_section( 'static_front_page' )->priority = 110;
	}

	$wpc->add_section( 'other', array(
		'title'       => esc_html_x( 'Other', 'customizer section title', 'potenza' ),
		'description' => esc_html__( 'Other options affecting the whole site.', 'potenza' ),
		'priority'    => 130
	) );



	//
	// Group options by registering the setting first, and the control right after.
	//

	//
	// Layout
	//
	$wpc->add_setting( 'layout_blog', array(
		'default'           => 'sidebar',
		'sanitize_callback' => 'potenza_sanitize_blog_layout',
	) );
	$wpc->add_control( 'layout_blog', array(
		'type'        => 'select',
		'section'     => 'layout',
		'label'       => esc_html__( 'Blog Layout', 'potenza' ),
		'description' => esc_html__( 'Applies to the blog page and blog-related pages.', 'potenza' ),
		'choices'     => array(
			'sidebar'   => esc_html_x( 'With Sidebar', 'blog layout', 'potenza' ),
			'fullwidth' => esc_html_x( 'Full Width', 'blog layout', 'potenza' ),
		),
	) );

	$wpc->add_setting( 'excerpt_length', array(
		'default'           => 55,
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( 'excerpt_length', array(
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 10,
			'step' => 1,
		),
		'section'     => 'layout',
		'label'       => esc_html__( 'Automatically generated excerpt length (in words)', 'potenza' ),
	) );

	$wpc->add_setting( 'pagination_method', array(
		'default'           => 'numbers',
		'sanitize_callback' => 'potenza_sanitize_pagination_method',
	) );
	$wpc->add_control( 'pagination_method', array(
		'type'    => 'select',
		'section' => 'layout',
		'label'   => esc_html__( 'Pagination method', 'potenza' ),
		'choices' => array(
			'numbers' => esc_html_x( 'Numbered links', 'pagination method', 'potenza' ),
			'text'    => esc_html_x( '"Previous - Next" links', 'pagination method', 'potenza' ),
		),
	) );


	//
	// Header
	//
	$wpc->add_setting( 'header_sticky', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_sticky', array(
		'type'    => 'checkbox',
		'section' => 'header',
		'label'   => esc_html__( 'Sticky header.', 'potenza' ),
	) );

	$wpc->add_setting( 'logo_padding_top', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'logo_padding_top', array(
		'type'    => 'number',
		'section' => 'header',
		'label'   => esc_html__( 'Logo top padding', 'potenza' ),
	) );

	$wpc->add_setting( 'logo_padding_bottom', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'logo_padding_bottom', array(
		'type'    => 'number',
		'section' => 'header',
		'label'   => esc_html__( 'Logo bottom padding', 'potenza' ),
	) );

	$wpc->add_setting( 'header_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_bg_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_border_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Border color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_link_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Link color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_hover_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Hover color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_hover_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_hover_bg_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Hover background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_subnav_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_bg_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Sub-menu background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_subnav_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_link_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Sub-menu link color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'header_subnav_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_hover_color', array(
		'section' => 'header',
		'label'   => esc_html__( 'Sub-menu hover color', 'potenza' ),
	) ) );



	//
	// Typography
	//
	$wpc->add_setting( 'h1_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h1_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H1 size', 'potenza' ),
	) );

	$wpc->add_setting( 'h2_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h2_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H2 size', 'potenza' ),
	) );

	$wpc->add_setting( 'h3_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h3_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H3 size', 'potenza' ),
	) );

	$wpc->add_setting( 'h4_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h4_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H4 size', 'potenza' ),
	) );

	$wpc->add_setting( 'h5_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h5_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H5 size', 'potenza' ),
	) );

	$wpc->add_setting( 'h6_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h6_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'H6 size', 'potenza' ),
	) );

	$wpc->add_setting( 'body_text_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'body_text_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Body text size', 'potenza' ),
	) );

	$wpc->add_setting( 'widgets_title_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'widgets_title_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Widgets title size', 'potenza' ),
	) );



	//
	// Global colors
	//
	$wpc->get_control( 'background_image' )->section      = 'colors';
	$wpc->get_control( 'background_repeat' )->section     = 'colors';
	$wpc->get_control( 'background_attachment' )->section = 'colors';
	if ( ! is_null( $wpc->get_control( 'background_position_x' ) ) ) {
		$wpc->get_control( 'background_position_x' )->section = 'colors';
	} else {
		$wpc->get_control( 'background_position' )->section = 'colors';
		$wpc->get_control( 'background_preset' )->section   = 'colors';
		$wpc->get_control( 'background_size' )->section     = 'colors';
	}

	$wpc->add_setting( 'primary_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'primary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Primary color', 'potenza' ),
		'description'   => esc_html__( 'Accent color.', 'potenza' ),
	) ) );

	$wpc->add_setting( 'site_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'site_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_link_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Link color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'site_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_hover_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Hover color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'site_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_border_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Border color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'button_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'button_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button text color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'button_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_border_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button border color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'button_bg_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_bg_hover_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button background hover color', 'potenza' ),
	) ) );



	//
	// Sidebar colors
	//
	$wpc->add_setting( 'widgets_title_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'widgets_title_bg_color', array(
		'section' => 'sidebar',
		'label'   => esc_html__( 'Widget title background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'widgets_title_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'widgets_title_color', array(
		'section' => 'sidebar',
		'label'   => esc_html__( 'Widget title color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'widgets_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'widgets_text_color', array(
		'section' => 'sidebar',
		'label'   => esc_html__( 'Widget text color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'widgets_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'widgets_link_color', array(
		'section' => 'sidebar',
		'label'   => esc_html__( 'Widget link color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'widgets_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'widgets_hover_color', array(
		'section' => 'sidebar',
		'label'   => esc_html__( 'Widget hover color', 'potenza' ),
	) ) );


	//
	// Social
	//
	$wpc->add_setting( 'social_target', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'social_target', array(
		'type'    => 'checkbox',
		'section' => 'social',
		'label'   => esc_html__( 'Open social and sharing links in a new tab.', 'potenza' ),
	) );

	$networks = potenza_get_social_networks();

	foreach ( $networks as $network ) {
		$wpc->add_setting( 'social_' . $network['name'], array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		) );
		$wpc->add_control( 'social_' . $network['name'], array(
			'type'    => 'url',
			'section' => 'social',
			'label'   => sprintf( _x( '%s URL', 'social network url', 'potenza' ), $network['label'] ),
		) );
	}

	$wpc->add_setting( 'rss_feed', array(
		'default'           => get_bloginfo( 'rss2_url' ),
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( 'rss_feed', array(
		'type'    => 'url',
		'section' => 'social',
		'label'   => esc_html__( 'RSS Feed', 'potenza' ),
	) );



	//
	// Single Post
	//
	$wpc->add_setting( 'single_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show categories.', 'potenza' ),
	) );

	$wpc->add_setting( 'single_date', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_date', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show date.', 'potenza' ),
	) );

	$wpc->add_setting( 'single_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show comments.', 'potenza' ),
	) );

	$wpc->add_setting( 'single_authorbox', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_authorbox', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show author box.', 'potenza' ),
	) );

	$wpc->add_setting( 'single_related', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_related', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show related posts.', 'potenza' ),
	) );

	$wpc->add_setting( 'single_related_title', array(
		'default'           => esc_html__( 'You may also like', 'potenza' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'single_related_title', array(
		'type'    => 'text',
		'section' => 'single_post',
		'label'   => esc_html__( 'Related Posts section title', 'potenza' ),
	) );



	//
	// Other
	//
	$wpc->add_setting( 'custom_css', array(
		'default'              => '',
		'sanitize_callback'    => 'potenza_sanitize_custom_css',
		'sanitize_js_callback' => 'potenza_sanitize_custom_css',
	) );
	$wpc->add_control( 'custom_css', array(
		'type'    => 'textarea',
		'section' => 'other',
		'label'   => esc_html__( 'Custom CSS', 'potenza' ),
	) );

	$wpc->add_setting( 'google_maps_api_enable', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'google_maps_api_enable', array(
		'type'        => 'checkbox',
		'section'     => 'other',
		'label'       => esc_html__( 'Enable Google Maps API.', 'potenza' ),
		'description' => esc_html__( 'The Google Maps API must only be loaded once in each page. Since many plugins may try to load it as well, you might want to disable it from the theme to avoid potential errors.', 'potenza' ),
	) );

	$wpc->add_setting( 'google_maps_api_key', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'google_maps_api_key', array(
		'type'        => 'text',
		'section'     => 'other',
		'label'       => esc_html__( 'Google Maps API key', 'potenza' ),
		'description' => sprintf( __( 'Paste here your Google Maps API Key. Maps will <strong>not</strong> be displayed without an API key. You need to issue a key from <a href="%1$s" target="_blank">Google Accounts</a>, and make sure the <strong>Google Maps JavaScript API</strong> is enabled. For instructions on issuing an API key, <a href="%2$s" target="_blank">read this article</a>.', 'potenza' ),
			'https://code.google.com/apis/console/',
			'https://www.cssigniter.com/docs/article/generate-a-google-maps-api-key/'
		),
	) );

	$wpc->add_setting( 'google_anaytics_tracking_id', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'google_anaytics_tracking_id', array(
		'type'        => 'text',
		'section'     => 'other',
		'label'       => esc_html__( 'Google Analytics Tracking ID', 'potenza' ),
		'description' => wp_kses( sprintf( __( 'Tracking is enabled only for the non-admin portion of your website. If you need fine-grained control of the tracking code, you are strongly adviced to <a href="%s" target="_blank">use a specialty plugin</a> instead.', 'potenza' ), 'https://wordpress.org/plugins/search.php?q=analytics' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ),
	) );


	$sample_content_url = apply_filters( 'potenza_sample_content_url',
		sprintf( 'https://www.cssigniter.com/sample_content/%s.zip', POTENZA_NAME ),
		'https://www.cssigniter.com/sample_content/',
		POTENZA_NAME
	);

	if ( ! empty( $sample_content_url ) && ( ! defined( 'POTENZA_WHITELABEL' ) || POTENZA_WHITELABEL == false ) ) {
		$wpc->add_setting( 'sample_content_link', array(
			'default' => '',
		) );
		$wpc->add_control( new Potenza_Customize_Static_Text_Control( $wpc, 'sample_content_link', array(
			'section'     => 'other',
			'label'       => esc_html__( 'Resources', 'potenza' ),
			'description' => array(
				wp_kses(
					sprintf( __( '<a href="%s" target="_blank">Download the theme\'s sample content</a> to get things moving.', 'potenza' ),
						esc_url( $sample_content_url )
					),
					potenza_get_allowed_tags( 'guide' )
				),
			),
		) ) );
	}


	//
	// Footer
	//
	$wpc->add_setting( 'footer_text', array(
		'default'           => sprintf( '<a href="%s">%s</a> &ndash; %s',
			esc_attr( home_url( '/' ) ),
			get_bloginfo( 'name' ),
			get_bloginfo( 'description' )
		),
		'sanitize_callback' => 'potenza_sanitize_footer_text',
	) );
	$wpc->add_control( 'footer_text', array(
		'type'        => 'text',
		'section'     => 'footer',
		'label'       => esc_html__( 'Footer text', 'potenza' ),
		'description' => esc_html__( 'Allowed tags: a (href|class), img (src|class), span (class), i (class), b, em, strong.', 'potenza' ),
	) );

	$wpc->add_setting( 'footer_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_bg_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Background color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'footer_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_text_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Text color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'footer_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_link_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Link color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'footer_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_hover_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Hover color', 'potenza' ),
	) ) );

	$wpc->add_setting( 'footer_socials', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'footer_socials', array(
		'type'    => 'checkbox',
		'section' => 'footer',
		'label'   => esc_html__( 'Show social icons.', 'potenza' ),
	) );



	//
	// site_tagline Section
	//
	$wpc->add_setting( 'limit_logo_size', array(
		'default'           => '',
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'limit_logo_size', array(
		'type'     => 'checkbox',
		'section'  => 'title_tagline',
		'priority' => 8,
		'label'    => esc_html__( 'Limit logo size (for Retina display)', 'potenza' ),
		'description' => esc_html__( 'This option will limit the logo size to half its width. You will need to upload your logo in 2x the dimension you want to display it in.', 'potenza' )
	) );

	$wpc->add_setting( 'logo_site_title', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'logo_site_title', array(
		'type'    => 'checkbox',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Show site title below the logo.', 'potenza' ),
	) );

	$wpc->add_setting( 'logo_tagline', array(
		'default'           => 1,
		'sanitize_callback' => 'potenza_sanitize_checkbox',
	) );
	$wpc->add_control( 'logo_tagline', array(
		'type'    => 'checkbox',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Show the tagline below the logo.', 'potenza' ),
	) );

}

add_action( 'customize_register', 'potenza_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function potenza_customize_register_custom_controls( $wpc ) {
	require get_template_directory() . '/inc/customizer-controls/static-text.php';
}
