<?php
if ( ! class_exists( 'CI_Widget_Custom_Content' ) ):
	class CI_Widget_Custom_Content extends WP_Widget {

		protected $defaults = array(
			'title'             => '',
			'subtitle'          => '',
			'text_position'     => 'left',
			'text'              => '',
			'button_text'       => '',
			'button_url'        => '',
			'image_id'          => '',
			'effects_enabled'   => '',
			'text_color'        => '',
			'background_color'  => '',
			'background_image'  => '',
			'background_repeat' => 'repeat',
			'overlay_color'     => '',
			'parallax'          => '',
			'parallax_speed'    => 4,
			'extra_padding'     => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Custom content area.', 'potenza' ) );
			$control_ops = array();
			parent::__construct( 'ci-custom-content', $name = esc_html__( 'Theme - Custom content', 'potenza' ), $widget_ops, $control_ops );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_custom_css' ) );

			// These are needed for the renaming of 'layover_color' to 'overlay_color'
			add_filter( 'widget_display_callback', array( $this, '_rename_old_overlay_field' ), 10, 2 );
			add_filter( 'widget_form_callback', array( $this, '_rename_old_overlay_field' ), 10, 2 );
		}

		// This is needed for the renaming of 'layover_color' to 'overlay_color'
		function _rename_old_overlay_field( $instance, $_this ) {
			$old_field = 'layover_color';
			$class     = get_class( $this );

			if ( get_class($_this) == $class && ! isset( $instance['overlay_color'] ) && isset( $instance[ $old_field ] ) ) {
				$instance['overlay_color'] = $instance[ $old_field ];
				unset( $instance[ $old_field ] );
			}

			return $instance;
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = $args['id'];
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$subtitle      = $instance['subtitle'];
			$text_position = $instance['text_position'];
			$text          = $instance['text'];
			$button_text   = $instance['button_text'];
			$button_url    = $instance['button_url'];
			$image_id      = $instance['image_id'];

			$image_url = potenza_get_image_src( $image_id, 'potenza_hero' );

			$overlay_color    = $instance['overlay_color'];
			$background_color = $instance['background_color'];
			$background_image = $instance['background_image'];
			$parallax         = $instance['parallax'] == 1 ? 'parallax' : '';
			$parallax_speed   = $instance['parallax'] == 1 ? sprintf( 'data-speed="%s"', esc_attr( $instance['parallax_speed'] / 10 ) ) : '';
			$parallax_image   = $instance['parallax'] == 1 && ! empty( $background_image ) ? sprintf( 'data-image-src="%s" data-parallax="scroll" data-bleed="3"', esc_url( $background_image ) ) : '';
			$extra_padding    = $instance['extra_padding'] == 1 ? 'wrap-extra-pad' : '';

			if ( ! empty( $background_color ) || ! empty( $background_image ) ) {
				preg_match( '/class=(["\']).*?widget.*?\1/', $before_widget, $match );
				if ( ! empty( $match ) ) {
					$attr_class    = preg_replace( '/\bwidget\b/', 'widget widget-padded', $match[0], 1 );
					$before_widget = str_replace( $match[0], $attr_class, $before_widget );
				}
			}

			$animation_classes = $instance['effects_enabled'] == 1 ? 'wow fadeInUp' : '';

			echo $before_widget;

			?><div class="widget-wrap <?php echo esc_attr( $parallax . ' ' . $extra_padding ); ?>" <?php echo $parallax_speed; ?> <?php echo $parallax_image; ?>><?php

			if ( ! empty( $overlay_color ) ) {
				?><div class="widget-overlay" style="background-color: <?php echo esc_attr( $overlay_color ); ?>"></div><?php
			}

			if ( in_array( $id, potenza_get_fullwidth_sidebars() ) ) {
				?>
				<div class="container">
					<div class="row">
				<?php
			}


			$image_markup = '';
			ob_start();
				if ( ! empty( $image_url ) ) {
					$attachment = wp_prepare_attachment_for_js( $image_id );
					?>
					<figure class="hero-image">
						<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $attachment['alt'] ); ?>">
					</figure>
					<?php
				}
			$image_markup = ob_get_clean();

			$content_markup = '';
			ob_start();
				if ( $title ) {
					echo $args['before_title'] . $title . $args['after_title'];
				}

				if ( $subtitle ) {
					?><p class="section-subtitle"><?php echo esc_html( $subtitle ); ?></p><?php
				}

				if ( $text ) {
					?><div class="hero-content-text"><?php echo wpautop( $text ); ?></div><?php
				}

				if ( ! empty( $button_text ) && ! empty( $button_url ) ) {
					?><a href="<?php echo esc_url( $button_url ); ?>" class="btn <?php echo esc_attr( $animation_classes ); ?>"><?php echo esc_html( $button_text ); ?></a><?php
				}
			$content_markup = ob_get_clean();


			if ( empty( $image_url ) ) {
				?>
				<div class="col-lg-8 col-lg-offset-2 col-md-10 col-md-offset-1">
					<div class="hero-content text-center <?php echo esc_attr( $animation_classes ); ?>"><?php echo $content_markup; ?></div>
				</div>
				<?php
			} else {
				if ( $text_position == 'right' ) {
					?>
					<div class="col-sm-6 col-xs-12"><?php echo $image_markup; ?></div>
					<div class="col-sm-6 col-xs-12">
						<div class="hero-content text-left <?php echo esc_attr( $animation_classes ); ?>">
							<?php echo $content_markup; ?>
						</div>
					</div>
					<?php
				} elseif ( $text_position == 'left' ) {
					?>
					<div class="col-sm-6 col-xs-12 col-sm-push-6"><?php echo $image_markup; ?></div>
					<div class="col-sm-6 col-xs-12 col-sm-pull-6">
						<div class="hero-content text-left <?php echo esc_attr( $animation_classes ); ?>">
							<?php echo $content_markup; ?>
						</div>
					</div>
					<?php
				}

			}


			if ( in_array( $id, potenza_get_fullwidth_sidebars() ) ) {
				?>
					</div>
				</div>
				<?php
			}

			?></div><?php

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']         = sanitize_text_field( $new_instance['title'] );
			$instance['subtitle']      = sanitize_text_field( $new_instance['subtitle'] );
			$instance['text_position'] = in_array( $new_instance['text_position'], array( 'left', 'right' ) ) ? $new_instance['text_position'] : 'left';
			$instance['text']          = wp_kses_post( $new_instance['text'] );
			$instance['button_text']   = sanitize_text_field( $new_instance['button_text'] );
			$instance['button_url']    = esc_url_raw( $new_instance['button_url'] );
			$instance['image_id']      = potenza_sanitize_intval_or_empty( $new_instance['image_id'] );

			$instance['effects_enabled']   = potenza_sanitize_checkbox_ref( $new_instance['effects_enabled'] );
			$instance['text_color']        = potenza_sanitize_hex_color( $new_instance['text_color'] );
			$instance['background_color']  = potenza_sanitize_hex_color( $new_instance['background_color'] );
			$instance['background_image']  = esc_url_raw( $new_instance['background_image'] );
			$instance['background_repeat'] = in_array( $new_instance['background_repeat'], array( 'repeat', 'no-repeat', 'repeat-x', 'repeat-y' ) ) ? $new_instance['background_repeat'] : 'repeat';
			$instance['overlay_color']     = potenza_sanitize_rgba_color( $new_instance['overlay_color'] );
			$instance['parallax']          = potenza_sanitize_checkbox_ref( $new_instance['parallax'] );
			$instance['parallax_speed']    = absint( $new_instance['parallax_speed'] );
			$instance['extra_padding']     = potenza_sanitize_checkbox_ref( $new_instance['extra_padding'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title         = $instance['title'];
			$subtitle      = $instance['subtitle'];
			$text_position = $instance['text_position'];
			$text          = $instance['text'];
			$button_text   = $instance['button_text'];
			$button_url    = $instance['button_url'];
			$image_id      = $instance['image_id'];

			$effects_enabled   = $instance['effects_enabled'];
			$text_color        = $instance['text_color'];
			$background_color  = $instance['background_color'];
			$background_image  = $instance['background_image'];
			$background_repeat = $instance['background_repeat'];
			$overlay_color     = $instance['overlay_color'];
			$parallax          = $instance['parallax'];
			$parallax_speed    = $instance['parallax_speed'];
			$extra_padding     = $instance['extra_padding'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>"><?php esc_html_e( 'Subtitle:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtitle' ) ); ?>" type="text" value="<?php echo esc_attr( $subtitle ); ?>" class="widefat" /></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php esc_html_e( 'Text:', 'potenza' ); ?></label><textarea id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" class="widefat"><?php echo esc_textarea( $text ); ?></textarea></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>"><?php esc_html_e( 'Button URL:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_url' ) ); ?>" type="text" value="<?php echo esc_attr( $button_url ); ?>" class="widefat" /></p>

			<p>
				<label class="post-field-item"><?php esc_html_e( 'Image:', 'potenza' ); ?>
					<div class="ci-upload-preview">
						<div class="upload-preview">
							<?php if ( ! empty( $image_id ) ): ?>
								<?php
									$image_url = potenza_get_image_src( $image_id, 'potenza_featgal_small_thumb' );
									echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
										esc_url( $image_url ),
										esc_attr__( 'Remove image', 'potenza' )
									);
								?>
							<?php endif; ?>
						</div>
						<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $this->get_field_name( 'image_id' ) ); ?>" value="<?php echo esc_attr( $image_id ); ?>" />
						<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'potenza' ); ?>" />
					</div>
				</label>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'text_position' ) ); ?>"><?php esc_html_e( 'Text Position (only applicable when image exists):', 'potenza' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'text_position' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'text_position' ) ); ?>">
					<option value="left" <?php selected( 'left', $text_position ); ?>><?php echo esc_html_x( 'Left', 'text position', 'potenza' ); ?></option>
					<option value="right" <?php selected( 'right', $text_position ); ?>><?php echo esc_html_x( 'Right', 'text position', 'potenza' ); ?></option>
				</select>
			</p>

			<fieldset class="ci-collapsible">
				<legend><?php esc_html_e( 'Customize', 'potenza' ); ?> <i class="dashicons dashicons-arrow-down"></i></legend>
				<div class="elements">
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'effects_enabled' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'effects_enabled' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'effects_enabled' ) ); ?>" value="1" <?php checked( $effects_enabled, 1 ); ?> /><?php esc_html_e( 'Enable animation effect.', 'potenza' ); ?></label></p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php esc_html_e( 'Text Color:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" type="text" value="<?php echo esc_attr( $text_color ); ?>" class="colorpckr widefat"/></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>"><?php esc_html_e( 'Background Color:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_color' ) ); ?>" type="text" value="<?php echo esc_attr( $background_color ); ?>" class="colorpckr widefat"/></p>

					<p class="ci-collapsible-media"><label for="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>"><?php esc_html_e( 'Background Image:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_image' ) ); ?>" type="text" value="<?php echo esc_attr( $background_image ); ?>" class="ci-uploaded-url widefat"/><a href="#" class="button ci-media-button"><?php esc_html_e( 'Select', 'potenza' ); ?></a></p>
					<p>
						<label for="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>"><?php esc_html_e( 'Background Repeat:', 'potenza' ); ?></label>
						<select id="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'background_repeat' ) ); ?>">
							<option value="repeat" <?php selected( 'repeat', $background_repeat ); ?>><?php esc_html_e( 'Repeat', 'potenza' ); ?></option>
							<option value="repeat-x" <?php selected( 'repeat-x', $background_repeat ); ?>><?php esc_html_e( 'Repeat Horizontally', 'potenza' ); ?></option>
							<option value="repeat-y" <?php selected( 'repeat-y', $background_repeat ); ?>><?php esc_html_e( 'Repeat Vertically', 'potenza' ); ?></option>
							<option value="no-repeat" <?php selected( 'no-repeat', $background_repeat ); ?>><?php esc_html_e( 'No Repeat', 'potenza' ); ?></option>
						</select>
					</p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'overlay_color' ) ); ?>"><?php esc_html_e( 'Overlay Color:', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'overlay_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'overlay_color' ) ); ?>" type="text" value="<?php echo esc_attr( $overlay_color ); ?>" class="widefat alpha-color-picker" /></p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'parallax' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'parallax' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'parallax' ) ); ?>" value="1" <?php checked( $parallax, 1 ); ?> /><?php esc_html_e( 'Parallax effect (requires a background image).', 'potenza' ); ?></label></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'parallax_speed' ) ); ?>"><?php esc_html_e( 'Parallax speed (1-10):', 'potenza' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'parallax_speed' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'parallax_speed' ) ); ?>" type="number" min="1" max="10" step="1" value="<?php echo esc_attr( $parallax_speed ); ?>" class="widefat"/></p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'extra_padding' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>" value="1" <?php checked( $extra_padding, 1 ); ?> /><?php esc_html_e( 'Apply extra padding.', 'potenza' ); ?></label></p>
				</div>
			</fieldset>

			<?php
		} // form

		function enqueue_custom_css() {
			$settings = $this->get_settings();

			if ( empty( $settings ) ) {
				return;
			}

			foreach ( $settings as $instance_id => $instance ) {
				$id = $this->id_base . '-' . $instance_id;

				if ( ! is_active_widget( false, $id, $this->id_base ) ) {
					continue;
				}

				$instance = wp_parse_args( (array) $instance, $this->defaults );

				$sidebar_id      = false; // Holds the sidebar id that the widget is assigned to.
				$sidebar_widgets = wp_get_sidebars_widgets();
				if ( ! empty( $sidebar_widgets ) ) {
					foreach ( $sidebar_widgets as $sidebar => $widgets ) {
						// We need to check $widgets for emptiness due to https://core.trac.wordpress.org/ticket/14876
						if ( ! empty( $widgets ) && array_search( $id, $widgets ) !== false ) {
							$sidebar_id = $sidebar;
						}
					}
				}

				$text_color        = $instance['text_color'];
				$background_color  = $instance['background_color'];
				$background_image  = $instance['background_image'];
				$background_repeat = $instance['background_repeat'];

				$css         = '';
				$padding_css = '';

				if ( ! empty( $text_color ) ) {
					$css .= 'color: ' . $text_color . '; ';
				}
				if ( ! empty( $background_color ) ) {
					$css .= 'background-color: ' . $background_color . '; ';
				}
				if ( ! empty( $background_image ) ) {
					$css .= 'background-image: url(' . esc_url( $background_image ) . ');';
					$css .= 'background-repeat: ' . $background_repeat . ';';
				}

				if ( ! empty( $css ) || ! empty( $padding_css ) ) {
					$css = '#' . $id . ' .widget-wrap { ' . $css . $padding_css . ' } ' . PHP_EOL;
					wp_add_inline_style( 'potenza-style', $css );
				}

			}

		}

	} // class

	register_widget( 'CI_Widget_Custom_Content' );

endif;